import { ShaderModule } from "../../../lib/shader-module/shader-module.js";
import type { NumberArray3 } from "../../../lib/utils/uniform-types.js";
/** Lighting helper types */
export type Light = AmbientLight | PointLight | DirectionalLight;
export type AmbientLight = {
    type: 'ambient';
    color?: Readonly<NumberArray3>;
    intensity?: number;
};
export type PointLight = {
    type: 'point';
    position: Readonly<NumberArray3>;
    color?: Readonly<NumberArray3>;
    intensity?: number;
    attenuation?: Readonly<NumberArray3>;
};
export type DirectionalLight = {
    type: 'directional';
    direction: Readonly<NumberArray3>;
    color?: Readonly<NumberArray3>;
    intensity?: number;
};
export type LightingProps = {
    enabled?: boolean;
    lights?: Light[];
    /** @deprecated */
    ambientLight?: AmbientLight;
    /** @deprecated */
    pointLights?: PointLight[];
    /** @deprecated */
    directionalLights?: DirectionalLight[];
};
export type LightingUniforms = {
    enabled: number;
    ambientLightColor: Readonly<NumberArray3>;
    directionalLightCount: number;
    pointLightCount: number;
    lightType: number;
    lightColor0: Readonly<NumberArray3>;
    lightPosition0: Readonly<NumberArray3>;
    lightDirection0: Readonly<NumberArray3>;
    lightAttenuation0: Readonly<NumberArray3>;
    lightColor1: Readonly<NumberArray3>;
    lightPosition1: Readonly<NumberArray3>;
    lightDirection1: Readonly<NumberArray3>;
    lightAttenuation1: Readonly<NumberArray3>;
    lightColor2: Readonly<NumberArray3>;
    lightPosition2: Readonly<NumberArray3>;
    lightDirection2: Readonly<NumberArray3>;
    lightAttenuation2: Readonly<NumberArray3>;
};
/** UBO ready lighting module */
export declare const lighting: ShaderModule<LightingProps, LightingUniforms, {}>;
//# sourceMappingURL=lighting-uniforms.d.ts.map